import { Injectable } from '@angular/core';

@Injectable({
  providedIn: 'root',
})
export class ClassService {
  constructor() {}

  // FUNCTIONS

  public getClassDetails(className: string): any {
    switch (className) {
      case 'Fighter':
        return this.fighter;
      case 'Barbarian':
        return this.barbarian;
      case 'Cleric':
        return this.cleric;
      case 'Monk':
        return this.monk;
      default:
        return this.notImplementedYet;
    }
  }

  // CLASS DETAILS

  public monk: any = {
    title: 'Mönch',
    description: `
      <p>Monks are united in their ability to magically harness the energy that flows in their bodies. Whether channeled as a striking display of combat prowess or a subtler focus of defensive ability and speed, this energy infuses all that a monk does.</p>
      <h4>Class Features</h4>
      <p>As a monk, you gain the following class features.</p>
      <h5 id="toc1"><span>Hit Points</span></h5>
      <p><strong>Hit Dice:</strong> 1d8 per monk level<br />
      <strong>Hit Points at 1st Level:</strong> 8 + your Constitution modifier<br />
      <strong>Hit Points at Higher Levels:</strong> 1d8 (or 5) + your Constitution modifier per monk level after 1st</p>
      <h5 id="toc2"><span>Proficiencies</span></h5>
      <p><strong>Armor:</strong> None<br />
      <strong>Weapons:</strong> Simple weapons, shortswords<br />
      <strong>Tools:</strong> Choose one type of artisan's tools or one musical instrument<br />
      <strong>Saving Throws:</strong> Strength, Dexterity<br />
      <strong>Skills:</strong> Choose two from Acrobatics, Athletics, History, Insight, Religion, and Stealth</p>
      <h5 id="toc3"><span>Equipment</span></h5>
      <p>You start with the following equipment, in addition to the equipment granted by your background:</p>
      <ul>
      <li>(a) a shortsword or (b) any simple weapon</li>
      <li>(a) a dungeoneer's pack or (b) an explorer's pack</li>
      <li>10 darts</li>
      </ul>`,
    features: [
      {
        name: 'Unarmored Defense',
        level: 1,
        description: `
          <p>Beginning at 1st level, while you are wearing no armor and not wielding a shield, your AC equals 10 + your Dexterity modifier + your Wisdom modifier.</p>
          `,
      },
      {
        name: 'Martial Arts',
        level: 1,
        description: `
          <p>At 1st level, your practice of martial arts gives you mastery of combat styles that use unarmed strikes and monk weapons, which are shortswords and any simple melee weapons that don't have the two-handed or heavy property.</p>
          <p>You gain the following benefits while you are unarmed or wielding only monk weapons and you aren't wearing armor or wielding a shield:</p>
          <ul>
          <li>You can use Dexterity instead of Strength for the attack and damage rolls of your unarmed strikes and monk weapons.</li>
          </ul>
          <ul>
          <li>You can roll a d4 in place of the normal damage of your unarmed strike or monk weapon. This die changes as you gain monk levels, as shown in the Martial Arts column of the Monk table.</li>
          </ul>
          <ul>
          <li>When you use the Attack action with an unarmed strike or a monk weapon on your turn, you can make one unarmed strike as a bonus action. For example, if you take the Attack action and attack with a quarterstaff, you can also make an unarmed strike as a bonus action, assuming you haven't already taken a bonus action this turn.</li>
          </ul>
          <p>Certain monasteries use specialized forms of the monk weapons. For example, you might use a club that is two lengths of wood connected by a short chain (called a nunchaku) or a sickle with a shorter, straighter blade (called a kama). Whatever name you use for a monk weapon, you can use the game statistics provided for the weapon on the <a href="http://dnd5e.wikidot.com/weapons">Weapons</a> page.</p>
          `,
      },
      {
        name: 'Ki',
        level: 2,
        description: `
          <p>Starting at 2nd level, your training allows you to harness the mystic energy of ki. Your access to this energy is represented by a number of ki points. Your monk level determines the number of points you have, as shown in the Ki Points column of the Monk table.</p>
          <p>You can spend these points to fuel various ki features. You start knowing three such features: Flurry of Blows, Patient Defense, and Step of the Wind. You learn more ki features as you gain levels in this class.</p>
          <p>When you spend a ki point, it is unavailable until you finish a short or long rest, at the end of which you draw all of your expended ki back into yourself. You must spend at least 30 minutes of the rest meditating to regain your ki points.</p>
          <p>Some of your ki features require your target to make a saving throw to resist the feature's effects. The saving throw DC is calculated as follows:</p>
          <p><strong>Ki save DC</strong> = 8 + your proficiency bonus + your Wisdom modifier</p>
          <ul>
          <li><strong>Flurry of Blows.</strong> Immediately after you take the Attack action on your turn, you can spend 1 ki point to make two unarmed strikes as a bonus action.</li>
          </ul>
          <ul>
          <li><strong>Patient Defense.</strong> You can spend 1 ki point to take the Dodge action as a bonus action on your turn.</li>
          </ul>
          <ul>
          <li><strong>Step of the Wind.</strong> You can spend 1 ki point to take the Disengage or Dash action as a bonus action on your turn, and your jump distance is doubled for the turn.</li>
          </ul>`,
      },
      {
        name: 'Unarmored Movement',
        level: 2,
        description: `
          <p>Starting at 2nd level, your speed increases by 10 feet while you are not wearing armor or wielding a shield. This bonus increases when you reach certain monk levels, as shown in the Monk table.</p>
          <p>At 9th level, you gain the ability to move along vertical surfaces and across liquids on your turn without falling during the move.</p>
          `,
      },
      {
        name: 'Dedicated Weapons (Optional)',
        level: 2,
        description: `
        <p>Also at 2nd level, you train yourself to use a variety of weapons as monk weapons, not just simple melee weapons and shortswords. Whenever you finish a short or long rest, you can touch one weapon, focus your ki on it, and then count that weapon as a monk weapon until you use this feature again.</p>
          <p>The chosen weapon must meet these criteria:</p>
          <ul>
          <li>The weapon must be a simple or martial weapon.</li>
          </ul>
          <ul>
          <li>You must be proficient with it.</li>
          </ul>
          <ul>
          <li>It must lack the heavy and special properties.</li>
          </ul>`,
      },
      {
        name: 'Monasteric Tradition',
        level: 3,
        description: `
          <p>When you reach 3rd level, you commit yourself to a monastic tradition. Your tradition grants you features at 3rd level and again at 6th, 11th, and 17th level.</p>
            `,
      },
      {
        name: 'Deflect Missile',
        level: 3,
        description: `
        <p>Starting at 3rd level, you can use your reaction to deflect or catch the missile when you are hit by a ranged weapon attack. When you do so, the damage you take from the attack is reduced by 1d10 + your Dexterity modifier + your monk level.</p>
        <p>If you reduce the damage to 0, you can catch the missile if it is small enough for you to hold in one hand and you have at least one hand free. If you catch a missile in this way, you can spend 1 ki point to make a ranged attack with a range of 20/60 using the weapon or piece of ammunition you just caught, as part of the same reaction. You make this attack with proficiency, regardless of your weapon proficiencies, and the missile counts as a monk weapon for the attack.</p>
        `,
        ability: '',
      },
      {
        name: 'Ki-Fueled Attack (Optional)',
        level: 3,
        description: `
        <p>Also at 3rd level, if you spend 1 ki point or more as part of your action on your turn, you can make one attack with an unarmed strike or a monk weapon as a bonus action before the end of the turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
        <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Slow Fall',
        level: 4,
        description: `
        <p>Beginning at 4th level, you can use your reaction when you fall to reduce any falling damage you take by an amount equal to five times your monk level.</p>
        `,
        ability: '',
      },
      {
        name: 'Quickened Healing',
        level: 4,
        description: `
        <p>Also at 4th level, as an action, you can spend 2 ki points and roll a Martial Arts die. You regain a number of hit points equal to the number rolled plus your proficiency bonus.</p>
        `,
        ability: '',
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
        <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.</p>
        `,
      },
      {
        name: 'Stunning Strike',
        level: 5,
        description: `
        <p>Starting at 5th level, you can interfere with the flow of ki in an opponent's body. When you hit another creature with a melee weapon attack, you can spend 1 ki point to attempt a stunning strike. The target must succeed on a Constitution saving throw or be stunned until the end of your next turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Focused Aim (Optional)',
        level: 5,
        description: `
        <p>Also at 5th level, when you miss with an attack roll, you can spend 1 to 3 ki points to increase your attack roll by 2 for each of these ki points you spend, potentially turning the miss into a hit.</p>
        `,
        ability: '',
      },
      {
        name: 'Ki-Empowered Strikes',
        level: 6,
        description: `
        <p>Starting at 6th level, your unarmed strikes count as magical for the purpose of overcoming resistance and immunity to nonmagical attacks and damage.</p>
        `,
      },
      {
        name: 'Evasion',
        level: 7,
        description: `
        <p>At 7th level, your instinctive agility lets you dodge out of the way of certain area effects, such as a blue dragon's lightning breath or a fireball spell. When you are subjected to an effect that allows you to make a Dexterity saving throw to take only half damage, you instead take no damage if you succeed on the saving throw, and only half damage if you fail.</p>
        `,
      },
      {
        name: 'Stillness of Mind',
        level: 7,
        description: `
        <p>Starting at 7th level, you can use your action to end one effect on yourself that is causing you to be charmed or frightened.</p>
        `,
        ability: '',
      },
      {
        name: 'Purity of Blood',
        level: 10,
        description: `
        <p>At 10th level, your mastery of the ki flowing through you makes you immune to disease and poison.</p>
        `,
      },
      {
        name: 'Tongue of the Sun and Moon',
        level: 13,
        description: `
        <p>Starting at 13th level, you learn to touch the ki of other minds so that you understand all spoken languages. Moreover, any creature that can understand a language can understand what you say.</p>
        `,
      },
      {
        name: 'Diamond Soul',
        level: 14,
        description: `
        <p>Beginning at 14th level, your mastery of ki grants you proficiency in all saving throws.</p>
        `,
      },
      {
        name: 'Timeless Body',
        level: 15,
        description: `
        <p>At 15th level, your ki sustains you so that you suffer none of the frailty of old age, and you can't be aged magically. You can still die of old age, however. In addition, you no longer need food or water.</p>
        `,
      },
      {
        name: 'Empty Body',
        level: 18,
        description: `
        <p>Beginning at 18th level, you can use your action to spend 4 ki points to become invisible for 1 minute. During that time, you also have resistance to all damage but force damage.</p>
        <p>Additionally, you can spend 8 ki points to cast the <em><a href="/spell:astral-projection">astral projection</a></em> spell, without needing material components. When you do so, you can't take any other creatures with you.</p>
        `,
        ability: '',
      },
      {
        name: 'Perfect Self',
        level: 20,
        description: `
        <p>At 20th level, when you roll for initiative and have no ki points remaining, you regain 4 ki points.</p>
        `,
      },
    ],
  };

  public fighter: any = {
    title: 'Kämpfer',
    description: `
    <p>Fighters share an unparalleled mastery with weapons and armor, and a thorough knowledge of the skills of combat. They are well acquainted with death, both meting it out and staring it defiantly in the face.</p>
    <h4>Class Features</h4>
    <p>As a fighter, you gain the following class features.</p>

    <h4> Hit Points </h4>
    <b>Hit Dice:</b> 1d10 per fighter level <br>
    <b>Hit Points at 1st Level:</b> 10 + your Constitution modifier  <br>
    <b>Hit Points at Higher Levels:</b> 1d10 (or 6) + your Constitution modifier per fighter level after 1st  <br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> All armor, shields  <br>
    <b>Weapons:</b> Simple weapons, martial weapons  <br>
    <b>Tools:</b> None  <br>
    <b>Saving Throws:</b> Strength, Constitution <br>
    <b>Skills:</b> Choose two skills from Acrobatics, Animal Handling, Athletics, History, Insight, Intimidation, Perception, and Survival <br>
    <h4> Equipment</h4>
    <ul>
    <li>(a) chain mail or (b) leather, longbow, and 20 arrows</li>
    <li>(a) a martial weapon and a shield or (b) two martial weapons</li>
    <li>(a) a light crossbow and 20 bolts or (b) two handaxes</li>
    <li>(a) a dungeoneer's pack or (b) an explorer's pack</li>
    `,
    features: [
      {
        name: 'Fighting Style',
        level: 1,
        description: `
      <p>You adopt a particular style of fighting as your specialty. Choose one of the following options. You can't take a Fighting Style option more than once, even if you later get to choose again.<p>
      <ul>
        <li> Archery (PHB). You gain a +2 bonus to attack rolls you make with ranged weapons.</li>
        <li> Blind Fighting (TCE). You have blindsight with a range of 10 feet. Within that range, you can effectively see anything that isn't behind total cover, even if you're blinded or in darkness. Moreover, you can see an invisible creature within that range, unless the creature successfully hides from you.</li>
        <li> Defense (PHB). While you are wearing armor, you gain a +1 bonus to AC.</li>
        <li> Dueling (PHB). When you are wielding a melee weapon in one hand and no other weapons, you gain a +2 bonus to damage rolls with that weapon.</li>
        <li> Great Weapon Fighting (PHB). When you roll a 1 or 2 on a damage die for an attack you make with a melee weapon that you are wielding with two hands, you can reroll the die and must use the new roll, even if the new roll is a 1 or a 2. The weapon must have the two-handed or versatile property for you to gain this benefit.</li>
        <li> Interception (TCE). When a creature you can see hits a target, other than you, within 5 feet of you with an attack, you can use your reaction to reduce the damage the target takes by 1d10 + your proficiency bonus (to a minimum of 0 damage). You must be wielding a shield or a simple or martial weapon to use this reaction.</li>
        <li> Protection (PHB). When a creature you can see attacks a target other than you that is within 5 feet of you, you can use your reaction to impose disadvantage on the attack roll. You must be wielding a shield.</li>
        <li> Superior Technique (TCE). You learn one maneuver of your choice from among those available to the Battle Master archetype. If a maneuver you use requires your target to make a saving throw to resist the maneuver's effects, the saving throw DC equals 8 + your proficiency bonus + your Strength or Dexterity modifier (your choice.)</li>
        <li> You gain one superiority die, which is a d6 (this die is added to any superiority dice you have from another source). This die is used to fuel your maneuvers. A superiority die is expended when you use it. You regain your expended superiority dice when you finish a short or long rest.</li>
        <li> Thrown Weapon Fighting (TCE). You can draw a weapon that has the thrown property as part of the attack you make with the weapon.</li>
        <li> In addition, when you hit with a ranged attack using a thrown weapon, you gain a +2 bonus to the damage roll.</li>
        <li> Two-Weapon Fighting (PHB). When you engage in two-weapon fighting, you can add your ability modifier to the damage of the second attack.</li>
        <li> Unarmed Fighting (TCE). Your unarmed strikes can deal bludgeoning damage equal to 1d6 + your Strength modifier on a hit. If you aren't wielding any weapons or a shield when you make the attack roll, the d6 becomes a d8.</li>
        <li> At the start of each of your turns, you can deal 1d4 bludgeoning damage to one creature grappled by you.</li>
        <li> Close Quarters Shooter (UA). When making a ranged attack while you are within 5 feet of a hostile creature, you do not have disadvantage on the attack roll. Your ranged attacks ignore half cover and three-quarters cover against targets within 30 feet of you. You have a +1 bonus to attack rolls on ranged attacks.</li>
        <li> Mariner (UA). As long as you are not wearing heavy armor or using a shield, you have a swimming speed and a climbing speed equal to your normal speed, and you gain a +1 bonus to armor class.</li>
        <li> Tunnel Fighter (UA). As a bonus action, you can enter a defensive stance that lasts until the start of your next turn. While in your defensive stance, you can make opportunity attacks without using your reaction, and you can use your reaction to make a melee attack against a creature that moves more than 5 feet while within your reach.</li>
      </ul>
      `,
      },
      {
        name: 'Second Wind',
        level: 1,
        description: `
          <p>You have a limited well of stamina that you can draw on to protect yourself from harm. On your turn, you can use a bonus action to regain hit points equal to 1d10 + your fighter level.</p>
          <p>Once you use this feature, you must finish a short or long rest before you can use it again.</p>
        `,
        ability: '',
      },
      {
        name: 'Action Surge',
        level: 2,
        description: `
          <p> Starting at 2nd level, you can push yourself beyond your normal limits for a moment. On your turn, you can take one additional action.</p>
          <p>Once you use this feature, you must finish a short or long rest before you can use it again. Starting at 17th level, you can use it twice before a rest, but only once on the same turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Martial Archetype',
        level: 3,
        description: `
          <p>At 3rd level, you choose an archetype that you strive to emulate in your combat styles and techniques. The archetype you choose grants you features at 3rd level and again at 7th, 10th, 15th, and 18th level.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
          <p>When you reach 4th level, and again at 6th, 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
          <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.<p>
          <p>The number of attacks increases to three when you reach 11th level in this class and to four when you reach 20th level in this class.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 6,
        description: `
          <p>When you reach 6th level, and again at 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
          <p>When you reach 8th level, and again at 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable',
        level: 9,
        description: `
          <p>Beginning at 9th level, you can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest.</p>
        `,
      },
      {
        name: 'Extra Attack (x3)',
        level: 11,
        description: `
          <p>You can now attack three times whenever you take the Attack action on your turn.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 12th level, and again at 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable (x2)',
        level: 13,
        description: `
          <p>You can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest. You can now use this feature twice between long rests.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 14,
        description: `
          <p>When you reach 14th level, and again at 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
          <p>When you reach 16th level, and again at 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable (x3)',
        level: 17,
        description: `
          <p>You can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest. You can now use this feature thrice between long rests.</p>
        `,
      },
      {
        name: 'Action Surge (x2)',
        level: 17,
        description: `
          <p>Starting at 17th level, you can use it twice before a rest, but only once on the same turn.</p>

        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 19,
        description: `
         <p>When you reach 19th level you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Extra Attack (x4)',
        level: 20,
        description: `
          <p>You can now attack four times whenever you take the Attack action on your turn.</p>
        `,
      },
    ],
  };

  public barbarian: any = {
    title: 'Barbar',
    description: `
    <p>Barbarians are savage warriors who deal with their opponents through a combination of sheer brute force and terrifying rage. Their strength and ferocity make them well suited for melee combat. Barbarians are also able to wreak havoc on their enemies using unorthodox methods, such as throwing improvised weapons or even their own bodies.</p>
    <h4>Class Features</h4>
    <p>As a barbarian, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d12 per barbarian level <br>
    <b>Hit Points at 1st Level:</b> 12 + your Constitution modifier <br> 
    <b>Hit Points at Higher Levels:</b> 1d12 (or 7) + your Constitution modifier per barbarian level after 1st <br>
    <h4>Proficiencies</h4>
    <b>Armor:</b> Light armor, medium armor, shields <br>
    <b>Weapons:</b> Simple weapons, martial weapons <br>
    <b>Tools:</b> None <br>
    <b>Saving Throws:</b> Strength, Constitution <br>
    <b>Skills:</b> Choose two skills from Animal Handling, Athletics, Intimidation, Nature, Perception, and Survival

    <h4>Equipment</h4>
    <ul>
    <li> (a) a greataxe or (b) any martial melee weapon </li>
    <li> (a) two handaxes or (b) any simple weapon </li>
    <li> An explorer's pack and four javelins </li>
    </ul>
    `,
    features: [
      {
        name: 'Rage',
        level: 1,
        description: `
        <p>In battle, you fight with primal ferocity. On your turn, you can enter a rage as a bonus action.</p>
        <p>While raging, you gain the following benefits if you aren't wearing heavy armor:</p>
        <ul>
          <li> You have advantage on Strength checks and Strength saving throws. </li>
          <li> When you make a melee weapon attack using Strength, you gain a bonus to the damage roll that increases as you gain levels as a barbarian, as shown in the Rage Damage column of the Barbarian table. </li>  
          <li> You have resistance to bludgeoning, piercing, and slashing damage. </li>
          <li> If you are able to cast spells, you can't cast them or concentrate on them while raging. </li>
          <li> Your rage lasts for 1 minute. It ends early if you are knocked unconscious or if your turn ends and you haven't attacked a hostile creature since your last turn or taken damage since then. You can also end your rage on your turn as a bonus action. </li>
          <li> Once you have raged the number of times shown for your barbarian level in the Rages column of the Barbarian table, you must finish a long rest before you can rage again. </li>
        <ul>
          `,
        ability: '',
      },
      {
        name: 'Unarmored Defense',
        level: 1,
        description: `
          <p>While you are not wearing any armor, your Armor Class equals 10 + your Dexterity modifier + your Constitution modifier. You can use a shield and still gain this benefit. </p>
        `,
      },
      {
        name: 'Reckless Attack',
        level: 2,
        description: `
          <p>Starting at 2nd level, you can throw aside all concern for defense to attack with fierce desperation. When you make your first attack on your turn, you can decide to attack recklessly. Doing so gives you advantage on melee weapon attack rolls using Strength during this turn, but attack rolls against you have advantage until your next turn. </p>
        `,
        ability: '',
      },
      {
        name: 'Danger Sense',
        level: 2,
        description: `
          <p>At 2nd level, you gain an uncanny sense of when things nearby aren't as they should be, giving you an edge when you dodge away from danger. </p>
          <p>You have advantage on Dexterity saving throws against effects that you can see, such as traps and spells. To gain this benefit, you can't be blinded, deafened, or incapacitated. <p>
        `,
      },
      {
        name: 'Primal Path',
        level: 3,
        description: `
          <p>At 3rd level, you choose a path that shapes the nature of your rage. Choose the Path of the Berserker or the Path of the Totem Warrior, both detailed at the end of the class description. Your choice grants you features at 3rd level and again at 6th, 10th, and 14th levels. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
         <p> When you reach 4th level, and again at 6th, 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.  </p>
        `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
          <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.<p>
          <p>The number of attacks increases to three when you reach 11th level in this class and to four when you reach 20th level in this class.  </p>  
        `,
      },
      {
        name: 'Fast Movement',
        level: 5,
        description: `
          <p>Starting at 5th level, your speed increases by 10 feet while you aren't wearing heavy armor. </p>
        `,
      },
      {
        name: 'Feral Instinct',
        level: 7,
        description: `
          <p>By 7th level, your instincts are so honed that you have advantage on initiative rolls.</p>
         <p> Additionally, if you are surprised at the beginning of combat and aren't incapacitated, you can act normally on your first turn, but only if you enter your rage before doing anything else on that turn. </p>
        `,
      },
      {
        name: 'Brutal Critical',
        level: 9,
        description: `
          <p>Beginning at 9th level, you can roll one additional weapon damage die when determining the extra damage for a critical hit with a melee attack. </p>
          <p>This increases to two additional dice at 13th level and three additional dice at 17th level. </p>
        `,
      },
      {
        name: 'Relentless Rage',
        level: 11,
        description: `
          <p>Starting at 11th level, your rage can keep you fighting despite grievous wounds. If you drop to 0 hit points while you're raging and don't die outright, you can make a DC 10 Constitution saving throw. If you succeed, you drop to 1 hit point instead. </p>
          <p>Each time you use this feature after the first, the DC increases by 5. When you finish a short or long rest, the DC resets to 10. </p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 12th level, and again at 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
        `,
      },
      {
        name: 'Persistent Rage',
        level: 15,
        description: `
          <p>Beginning at 15th level, your rage is so fierce that it ends early only if you fall unconscious or if you choose to end it. <p>
        `,
      },
      {
        name: 'Indomitable Might',
        level: 18,
        description: `
          <p>Beginning at 18th level, if your total for a Strength check is less than your Strength score, you can use that score in place of the total.</p>
        `,
      },
      {
        name: 'Primal Champion',
        level: 20,
        description: `
          <p>At 20th level, you embody the power of the wilds. Your Strength and Constitution scores increase by 4. Your maximum for those scores is now 24. </p>
        `,
      },
    ],
  };

  public cleric: any = {
    title: 'Cleric',
    description: `
    <p>Clerics are intermediaries between the mortal world and the distant planes of the gods. As varied as the gods they serve, clerics strive to embody the handiwork of their deities. No ordinary priest, a cleric is imbued with divine magic.</p>
    <h4>Class Features</h4>
    <p>As a cleric, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d8 per cleric level <br>
    <b>Hit Points at 1st Level:</b> 8 + your Constitution modifier<br>
    <b>Hit Points at Higher Levels:</b> 1d8 (or 5) + your Constitution modifier per cleric level after 1st<br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> Light armor, medium armor, shields<br>
    <b>Weapons:</b> Simple weapons<br>
    <b>Tools:</b> None<br>
    <b>Saving Throws:</b> Wisdom, Charisma<br>
    <b>Skills:</b> Choose two from History, Insight, Medicine, Persuasion, and Religion<br>
    <h4> Equipment</h4>
    <ul>
    <li> (a) a mace or (b) a warhammer (if proficient)</li>
    <li> (a) scale mail, (b) leather armor, or (c) chain mail (if proficient)</li>
    <li> (a) a light crossbow and 20 bolts or (b) any simple weapon</li>
    <li> (a) a priest's pack or (b) an explorer's pack</li>
    <li> A shield and a holy symbol</li>
    <ul>
    `,
    features: [
      {
        name: 'Spellcasting',
        level: 1,
        description: `
        <b>Cantrips</b>
        <p>At 1st level, you know three cantrips of your choice from the cleric spell list. You learn additional cleric cantrips of your choice at higher levels, as shown in the Cantrips Known column of the Cleric table.</p>
        <b>Spell Slots</b>
        <p>The Cleric table shows how many spell slots you have to cast your cleric spells of 1st level and higher. To cast one of these spells, you must expend a slot of the spell's level or higher. You regain all expended spell slots when you finish a long rest.</p>
        <p>You prepare the list of cleric spells that are available for you to cast, choosing from the cleric spell list. When you do so, choose a number of cleric spells equal to your Wisdom modifier + your cleric level (minimum of one spell). The spells must be of a level for which you have spell slots.</p>
        <p>For example, if you are a 3rd-level cleric, you have four 1st-level and two 2nd-level spell slots. With a Wisdom of 16, your list of prepared spells can include six spells of 1st or 2nd level, in any combination. If you prepare the 1st-level spell Cure Wounds, you can cast it using a 1st-level or 2nd-level slot. Casting the spell doesn't remove it from your list of prepared spells.</p>
        <p>You can change your list of prepared spells when you finish a long rest. Preparing a new list of cleric spells requires time spent in prayer and meditation: at least 1 minute per spell level for each spell on your list.</p>
        <h4>Spellcasting Ability</h4>
        <p>Wisdom is your spellcasting ability for your cleric spells. The power of your spells comes from your devotion to your deity. You use your Wisdom whenever a cleric spell refers to your spellcasting ability. In addition, you use your Wisdom modifier when setting the saving throw DC for a cleric spell you cast and when making an attack roll with one.</p>
        <b>Spell save DC:</b> 8 + your proficiency bonus + your Wisdom modifier<br>
        <b>Spell attack modifier:</b> your proficiency bonus + your Wisdom modifier<br>
        `,
      },
      {
        name: 'Divine Domain',
        level: 1,
        description: `
          <p>At 1st level, you choose a domain shaped by your choice of Deity and the gifts they grant you. Your choice grants you domain spells and other features when you choose it at 1st level. It also grants you additional ways to use Channel Divinity when you gain that feature at 2nd level, and additional benefits at 6th, 8th, and 17th levels.</p>
          `,
      },
      {
        name: 'Channel Divinity',
        level: 2,
        description: `
          <p>At 2nd level, you gain the ability to channel divine energy directly from your deity, using that energy to fuel magical effects. You start with two such effects: Turn Undead and an effect determined by your domain. Some domains grant you additional effects as you advance in levels, as noted in the domain description.</p>
          <p>When you use your Channel Divinity, you choose which effect to create. You must then finish a short or long rest to use your Channel Divinity again.</p>
          <p>Some Channel Divinity effects require saving throws. When you use such an effect from this class, the DC equals your cleric spell save DC.</p>
          <p>Beginning at 6th level, you can use your Channel Divinity twice between rests, and beginning at 18th level, you can use it three times between rests. When you finish a short or long rest, you regain your expended uses.</p>
          `,
      },
      {
        name: 'Channel Divinity Turn Undead',
        level: 2,
        description: `
          <p>As an action, you present your holy symbol and speak a prayer censuring the undead. Each undead that can see or hear you within 30 feet of you must make a Wisdom saving throw. If the creature fails its saving throw, it is turned for 1 minute or until it takes any damage.</p>
          <p>A turned creature must spend its turns trying to move as far away from you as it can, and it can't willingly move to a space within 30 feet of you. It also can't take reactions. For its action, it can use only the Dash action or try to escape from an effect that prevents it from moving. If there's nowhere to move, the creature can use the Dodge action.</p>
          `,
        ability: '',
      },
      {
        name: 'Harness Divine Power',
        level: 2,
        description: `
          <p>At 2nd level, you can expend a use of your Channel Divinity to fuel your spells. As a bonus action, you touch your holy symbol, utter a prayer, and regain one expended spell slot, the level of which can be no higher than half your proficiency bonus (rounded up). The number of times you can use this feature is based on the level you've reached in this class: 2nd level, once; 6th level, twice; and 18th level, thrice. You regain all expended uses when you finish a long rest.<p>
          `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
          <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Destroy Undead',
        level: 5,
        description: `
          <p>Starting at 5th level, when an undead fails its saving throw against your Turn Undead feature, the creature is instantly destroyed if its challenge rating is at or below a certain threshold, as shown in the Cleric table above.</p>`,
      },
      {
        name: 'Blessed Strikes',
        level: 8,
        description: `
          <p>Replaces the Divine Strike or Potent Spellcasting feature</p>
          <p>When you reach 8th level, you are blessed with divine might in battle. When a creature takes damage from one of your cantrips or weapon attacks, you can also deal 1d8 radiant damage to that creature. Once you deal this damage, you can't use this feature again until the start of your next turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
          <p>When you reach 8th level, and again at 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Divine Intervention',
        level: 10,
        description: `
          <p>Beginning at 10th level, you can call on your deity to intervene on your behalf when your need is great.</p>
          <p>Imploring your deity's aid requires you to use your action. Describe the assistance you seek, and roll percentile dice. If you roll a number equal to or lower than your cleric level, your deity intervenes. The GM chooses the nature of the intervention; the effect of any cleric spell or cleric domain spell would be appropriate.</p>
          <p>If your deity intervenes, you can't use this feature again for 7 days. Otherwise, you can use it again after you finish a long rest.</p>
          <p>At 20th level, your call for intervention succeeds automatically, no roll required.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 4th level, and again at 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
          <p>When you reach 4th level, and again at 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 19,
        description: `
          <p>When you reach 19th level you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
    ],
  };

  private notImplementedYet: any = {
    title: 'Not implemented yet',
    description: `
    This class is not implemented yet, please check back later.
    `,
    features: [],
  };
}
